@@ -24,6 +24,7 @@
 #include "QtUtils.h"
 #include "SourceCompatibilityHelpers.h"
 #include "Utils.h"
+#include "ClazyContext.h"
 
 #include <clang/Basic/SourceManager.h>
 #include <clang/AST/DeclCXX.h>
@@ -140,9 +141,10 @@ public:
     ClazySpecifierList m_qtAccessSpecifiers;
 };
 
-AccessSpecifierManager::AccessSpecifierManager(const clang::CompilerInstance &ci)
-    : m_ci(ci)
-    , m_preprocessorCallbacks(new AccessSpecifierPreprocessorCallbacks(ci))
+AccessSpecifierManager::AccessSpecifierManager(ClazyContext *context)
+    : m_ci(context->ci)
+    , m_preprocessorCallbacks(new AccessSpecifierPreprocessorCallbacks(m_ci))
+    , m_fixitsEnabled(context->exportFixesEnabled())
 {
     Preprocessor &pi = m_ci.getPreprocessor();
     pi.addPPCallbacks(unique_ptr<PPCallbacks>(m_preprocessorCallbacks));
@@ -167,9 +169,16 @@ const CXXRecordDecl *AccessSpecifierManager::classDefinitionForLoc(SourceLocatio
 void AccessSpecifierManager::VisitDeclaration(Decl *decl)
 {
     auto record = dyn_cast<CXXRecordDecl>(decl);
-    if (!clazy::isQObject(record))
+    if (!record)
         return;
 
+    if (!m_fixitsEnabled && !clazy::isQObject(record)) {
+        // We're only interested if it's a QObject. Otherwise it's a waste of cpu cycles,
+        // causing a big slowdown. However, the copyable-polymorphic fixit needs to know the locations
+        // of "private:", so allow that too
+        return;
+    }
+
     const auto &sm = m_ci.getSourceManager();
 
     // We got a new record, lets fetch signals and slots that the pre-processor gathered
@@ -177,7 +186,7 @@ void AccessSpecifierManager::VisitDeclaration(Decl *decl)
 
     auto it = m_preprocessorCallbacks->m_qtAccessSpecifiers.begin();
     while (it != m_preprocessorCallbacks->m_qtAccessSpecifiers.end()) {
-        if (classDefinitionForLoc((*it).loc) == record) {
+         if (classDefinitionForLoc((*it).loc) == record) {
             sorted_insert(specifiers, *it, sm);
             it = m_preprocessorCallbacks->m_qtAccessSpecifiers.erase(it);
         } else {
@@ -286,3 +295,18 @@ llvm::StringRef AccessSpecifierManager::qtAccessSpecifierTypeStr(QtAccessSpecifi
 
     return "";
 }
+
+SourceLocation AccessSpecifierManager::firstLocationOfSection(
+    AccessSpecifier specifier, clang::CXXRecordDecl *decl) const {
+
+    auto it = m_specifiersMap.find(decl);
+    if (it == m_specifiersMap.end())
+        return {};
+
+    for (const auto &record : it->second) {
+        if (record.accessSpecifier == specifier) {
+            return record.loc;
+        }
+    }
+    return {};
+}
