@@ -28,6 +28,7 @@
 #include "checkbase.h"
 #include "AccessSpecifierManager.h"
 #include "SourceCompatibilityHelpers.h"
+#include "FixItExporter.h"
 
 #include <clang/Frontend/FrontendPluginRegistry.h>
 #include <clang/Frontend/CompilerInstance.h>
@@ -106,15 +107,20 @@ bool ClazyASTConsumer::VisitDecl(Decl *decl)
     if (AccessSpecifierManager *a = m_context->accessSpecifierManager) // Needs to visit system headers too (qobject.h for example)
         a->VisitDeclaration(decl);
 
+    const bool isTypeDefToVisit = m_context->visitsAllTypedefs() && isa<TypedefNameDecl>(decl);
     const SourceLocation locStart = clazy::getLocStart(decl);
-    if (locStart.isInvalid() || m_context->sm.isInSystemHeader(locStart))
+    if (locStart.isInvalid() || (m_context->sm.isInSystemHeader(locStart) && !isTypeDefToVisit))
         return true;
 
     const bool isFromIgnorableInclude = m_context->ignoresIncludedFiles() && !Utils::isMainFile(m_context->sm, locStart);
 
     m_context->lastDecl = decl;
-    if (auto mdecl = dyn_cast<CXXMethodDecl>(decl))
-        m_context->lastMethodDecl = mdecl;
+
+    if (auto fdecl = dyn_cast<FunctionDecl>(decl)) {
+        m_context->lastFunctionDecl = fdecl;
+        if (auto mdecl = dyn_cast<CXXMethodDecl>(fdecl))
+            m_context->lastMethodDecl = mdecl;
+    }
 
     for (CheckBase *check : m_checksToVisitDecls) {
         if (!(isFromIgnorableInclude && check->canIgnoreIncludes()))
@@ -163,6 +169,10 @@ bool ClazyASTConsumer::VisitStmt(Stmt *stm)
 
 void ClazyASTConsumer::HandleTranslationUnit(ASTContext &ctx)
 {
+    // FIXME: EndSourceFile() is called automatically, but not BeginsSourceFile()
+    if (m_context->exporter)
+        m_context->exporter->BeginSourceFile(clang::LangOptions());
+
     if ((m_context->options & ClazyContext::ClazyOption_OnlyQt) && !m_context->isQt())
         return;
 
@@ -225,25 +235,17 @@ bool ClazyASTAction::ParseArgs(const CompilerInstance &ci, const std::vector<std
 
     const string headerFilter = getEnvVariable("CLAZY_HEADER_FILTER");
     const string ignoreDirs = getEnvVariable("CLAZY_IGNORE_DIRS");
+    std::string exportFixesFilename;
 
     if (parseArgument("help", args)) {
-        m_context = new ClazyContext(ci, headerFilter, ignoreDirs, ClazyContext::ClazyOption_None);
+        m_context = new ClazyContext(ci, headerFilter, ignoreDirs,
+                                     exportFixesFilename, {}, ClazyContext::ClazyOption_None);
         PrintHelp(llvm::errs());
         return true;
     }
 
-    if (parseArgument("no-inplace-fixits", args)) {
-        // Unit-tests don't use inplace fixits
-        m_options |= ClazyContext::ClazyOption_NoFixitsInplace;
-    }
-
-    if (parseArgument("enable-all-fixits", args)) {
-        // This is useful for unit-tests, where we also want to run fixits. Don't use it otherwise.
-        m_options |= ClazyContext::ClazyOption_AllFixitsEnabled;
-    }
-
-    if (parseArgument("no-autowrite-fixits", args))
-        m_options |= ClazyContext::ClazyOption_NoFixitsAutoWrite;
+    if (parseArgument("export-fixes", args) || getenv("CLAZY_EXPORT_FIXES"))
+        m_options |= ClazyContext::ClazyOption_ExportFixes;
 
     if (parseArgument("qt4-compat", args))
         m_options |= ClazyContext::ClazyOption_Qt4Compat;
@@ -260,14 +262,18 @@ bool ClazyASTAction::ParseArgs(const CompilerInstance &ci, const std::vector<std
     if (parseArgument("ignore-included-files", args))
         m_options |= ClazyContext::ClazyOption_IgnoreIncludedFiles;
 
-    m_context = new ClazyContext(ci, headerFilter, ignoreDirs, m_options);
+    if (parseArgument("export-fixes", args))
+        exportFixesFilename = args.at(0);
+
+    m_context = new ClazyContext(ci, headerFilter, ignoreDirs, exportFixesFilename, {}, m_options);
 
     // This argument is for debugging purposes
     const bool dbgPrintRequestedChecks = parseArgument("print-requested-checks", args);
 
     {
         std::lock_guard<std::mutex> lock(CheckManager::lock());
-        m_checks = m_checkManager->requestedChecks(m_context, args);
+        m_checks = m_checkManager->requestedChecks(args,
+                                                   m_options & ClazyContext::ClazyOption_Qt4Compat);
     }
 
     if (args.size() > 1) {
@@ -360,30 +366,34 @@ void ClazyASTAction::PrintHelp(llvm::raw_ostream &ros) const
     ros << "or pass as compiler arguments, for example:\n";
     ros << "    -Xclang -plugin-arg-clazy -Xclang reserve-candidates,qstring-allocations\n";
     ros << "\n";
-    ros << "To enable FixIts for a check, also set the env variable CLAZY_FIXIT, for example:\n";
-    ros << "    export CLAZY_FIXIT=\"fix-qlatin1string-allocations\"\n\n";
-    ros << "FixIts are experimental and rewrite your code therefore only one FixIt is allowed per build.\nSpecifying a list of different FixIts is not supported.\nBackup your code before running them.\n";
 }
 
-ClazyStandaloneASTAction::ClazyStandaloneASTAction(const string &checkList, const string &headerFilter, const string &ignoreDirs,
+ClazyStandaloneASTAction::ClazyStandaloneASTAction(const string &checkList,
+                                                   const string &headerFilter,
+                                                   const string &ignoreDirs,
+                                                   const string &exportFixesFilename,
+                                                   const std::vector<string> &translationUnitPaths,
                                                    ClazyContext::ClazyOptions options)
     : clang::ASTFrontendAction()
     , m_checkList(checkList.empty() ? "level1" : checkList)
     , m_headerFilter(headerFilter.empty() ? getEnvVariable("CLAZY_HEADER_FILTER") : headerFilter)
     , m_ignoreDirs(ignoreDirs.empty() ? getEnvVariable("CLAZY_IGNORE_DIRS") : ignoreDirs)
+    , m_exportFixesFilename(exportFixesFilename)
+    , m_translationUnitPaths(translationUnitPaths)
     , m_options(options)
 {
 }
 
 unique_ptr<ASTConsumer> ClazyStandaloneASTAction::CreateASTConsumer(CompilerInstance &ci, llvm::StringRef)
 {
-    auto context = new ClazyContext(ci, m_headerFilter, m_ignoreDirs, m_options);
+    auto context = new ClazyContext(ci, m_headerFilter, m_ignoreDirs, m_exportFixesFilename, m_translationUnitPaths, m_options);
     auto astConsumer = new ClazyASTConsumer(context);
 
     auto cm = CheckManager::instance();
 
     vector<string> checks; checks.push_back(m_checkList);
-    const RegisteredCheck::List requestedChecks = cm->requestedChecks(context, checks);
+    const bool qt4Compat = m_options & ClazyContext::ClazyOption_Qt4Compat;
+    const RegisteredCheck::List requestedChecks = cm->requestedChecks(checks, qt4Compat);
 
     if (requestedChecks.size() == 0) {
         llvm::errs() << "No checks were requested!\n" << "\n";
