@@ -36,28 +36,27 @@
 
 using namespace clang;
 
-bool TypeUtils::classifyQualType(const ClazyContext *context, const VarDecl *varDecl, QualTypeClassification &classif, clang::Stmt *body)
+bool clazy::classifyQualType(const ClazyContext *context, clang::QualType qualType,
+                             const VarDecl *varDecl, QualTypeClassification &classif,
+                             clang::Stmt *body)
 {
-    if (!varDecl)
-        return false;
-
-    QualType qualType = TypeUtils::unrefQualType(varDecl->getType());
-    const Type *paramType = qualType.getTypePtrOrNull();
+    QualType unrefQualType = clazy::unrefQualType(qualType);
+    const Type *paramType = unrefQualType.getTypePtrOrNull();
     if (!paramType || paramType->isIncompleteType())
         return false;
 
     if (isUndeducibleAuto(paramType))
         return false;
 
-    classif.size_of_T = context->astContext.getTypeSize(qualType) / 8;
+    classif.size_of_T = context->astContext.getTypeSize(unrefQualType) / 8;
     classif.isBig = classif.size_of_T > 16;
     CXXRecordDecl *recordDecl = paramType->getAsCXXRecordDecl();
     CXXMethodDecl *copyCtor = recordDecl ? Utils::copyCtor(recordDecl) : nullptr;
     classif.isNonTriviallyCopyable = recordDecl && (recordDecl->hasNonTrivialCopyConstructor() || recordDecl->hasNonTrivialDestructor() || (copyCtor && copyCtor->isDeleted()));
-    classif.isReference = varDecl->getType()->isLValueReferenceType();
-    classif.isConst = qualType.isConstQualified();
+    classif.isReference = qualType->isLValueReferenceType();
+    classif.isConst = unrefQualType.isConstQualified();
 
-    if (varDecl->getType()->isRValueReferenceType()) // && ref, nothing to do here
+    if (qualType->isRValueReferenceType()) // && ref, nothing to do here
         return true;
 
     if (classif.isConst && !classif.isReference) {
@@ -67,7 +66,7 @@ bool TypeUtils::classifyQualType(const ClazyContext *context, const VarDecl *var
         }
     } else if (classif.isConst && classif.isReference && !classif.isNonTriviallyCopyable && !classif.isBig) {
         classif.passSmallTrivialByValue = true;
-    } else if (!classif.isConst && !classif.isReference && (classif.isBig || classif.isNonTriviallyCopyable)) {
+    } else if (varDecl && !classif.isConst && !classif.isReference && (classif.isBig || classif.isNonTriviallyCopyable)) {
         if (body && (Utils::containsNonConstMemberCall(context->parentMap, body, varDecl) || Utils::isPassedToFunction(StmtBodyRange(body), varDecl, /*byrefonly=*/ true)))
             return true;
 
@@ -80,7 +79,43 @@ bool TypeUtils::classifyQualType(const ClazyContext *context, const VarDecl *var
     return true;
 }
 
-void TypeUtils::heapOrStackAllocated(Expr *arg, const std::string &type,
+bool clazy::isSmallTrivial(const ClazyContext *context, QualType qualType)
+{
+    if (qualType.isNull())
+        return false;
+
+    if (qualType->isPointerType())
+        qualType = qualType->getPointeeType();
+
+    if (qualType->isPointerType()) // We don't care about ** (We can change this whenever we have a use case)
+        return false;
+
+    QualType unrefQualType = clazy::unrefQualType(qualType);
+    const Type *paramType = unrefQualType.getTypePtrOrNull();
+    if (!paramType || paramType->isIncompleteType())
+        return false;
+
+    if (isUndeducibleAuto(paramType))
+        return false;
+
+    if (qualType->isRValueReferenceType()) // && ref, nothing to do here
+        return false;
+
+     CXXRecordDecl *recordDecl = paramType->getAsCXXRecordDecl();
+     CXXMethodDecl *copyCtor = recordDecl ? Utils::copyCtor(recordDecl) : nullptr;
+     const bool hasDeletedCopyCtor = copyCtor && copyCtor->isDeleted();
+     const bool isTrivial = recordDecl && !recordDecl->hasNonTrivialCopyConstructor() && !recordDecl->hasNonTrivialDestructor() && !hasDeletedCopyCtor;
+
+     if (isTrivial) {
+         const auto typeSize = context->astContext.getTypeSize(unrefQualType) / 8;
+         const bool isSmall = typeSize <= 16;
+         return isSmall;
+     }
+
+     return false;
+}
+
+void clazy::heapOrStackAllocated(Expr *arg, const std::string &type,
                                      const clang::LangOptions &lo,
                                      bool &isStack, bool &isHeap)
 {
@@ -121,7 +156,7 @@ void TypeUtils::heapOrStackAllocated(Expr *arg, const std::string &type,
     }
 }
 
-bool TypeUtils::derivesFrom(const CXXRecordDecl *derived, const CXXRecordDecl *possibleBase,
+bool clazy::derivesFrom(const CXXRecordDecl *derived, const CXXRecordDecl *possibleBase,
                             std::vector<CXXRecordDecl*> *baseClasses)
 {
     if (!derived || !possibleBase || derived == possibleBase)
@@ -143,7 +178,7 @@ bool TypeUtils::derivesFrom(const CXXRecordDecl *derived, const CXXRecordDecl *p
     return false;
 }
 
-bool TypeUtils::derivesFrom(const clang::CXXRecordDecl *derived, const std::string &possibleBase)
+bool clazy::derivesFrom(const clang::CXXRecordDecl *derived, const std::string &possibleBase)
 {
     if (!derived || !derived->hasDefinition())
         return false;
@@ -159,7 +194,7 @@ bool TypeUtils::derivesFrom(const clang::CXXRecordDecl *derived, const std::stri
     return false;
 }
 
-bool TypeUtils::derivesFrom(QualType derivedQT, const std::string &possibleBase)
+bool clazy::derivesFrom(QualType derivedQT, const std::string &possibleBase)
 {
     derivedQT = pointeeQualType(derivedQT);
     const auto t = derivedQT.getTypePtrOrNull();
