@@ -346,7 +346,7 @@ static bool isArgOfFunc(T expr, FunctionDecl *fDecl, const VarDecl *varDecl, boo
             continue;
 
         QualType qt = paramDecl->getType();
-        const Type *t = qt.getTypePtrOrNull();
+        const clang::Type *t = qt.getTypePtrOrNull();
         if (!t)
             continue;
 
@@ -922,7 +922,7 @@ string Utils::filenameForLoc(SourceLocation loc, const clang::SourceManager &sm)
     if (loc.isMacroID())
         loc = sm.getExpansionLoc(loc);
 
-    const string filename = sm.getFilename(loc);
+    const string filename = static_cast<string>(sm.getFilename(loc));
     auto splitted = clazy::splitString(filename, '/');
     if (splitted.empty())
         return {};
