@@ -23,6 +23,8 @@
 #include "ClazyContext.h"
 #include "QtUtils.h"
 #include "SourceCompatibilityHelpers.h"
+#include "FixItUtils.h"
+#include "PreProcessorVisitor.h"
 
 #include <clang/AST/DeclBase.h>
 #include <clang/AST/DeclCXX.h>
@@ -33,6 +35,10 @@
 #include <llvm/ADT/StringRef.h>
 #include <llvm/Support/Casting.h>
 
+#ifdef HAS_STD_FILESYSTEM
+# include <filesystem>
+#endif
+
 namespace clang {
 class MacroInfo;
 }  // namespace clang
@@ -44,6 +50,7 @@ MissingQObjectMacro::MissingQObjectMacro(const std::string &name, ClazyContext *
     : CheckBase(name, context)
 {
     enablePreProcessorCallbacks();
+    context->enablePreprocessorVisitor();
 }
 
 void MissingQObjectMacro::VisitMacroExpands(const clang::Token &MacroNameTok, const clang::SourceRange &range, const MacroInfo *)
@@ -75,7 +82,26 @@ void MissingQObjectMacro::VisitDecl(clang::Decl *decl)
             return; // We found a Q_OBJECT after start and before end, it's ours.
     }
 
-    emitWarning(startLoc, record->getQualifiedNameAsString() + " is missing a Q_OBJECT macro");
+    vector<FixItHint> fixits;
+#if LLVM_VERSION_MAJOR >= 11 // older llvm has problems with \n in the yaml file
+    const SourceLocation pos = record->getBraceRange().getBegin().getLocWithOffset(1);
+    fixits.push_back(clazy::createInsertion(pos, "\n\tQ_OBJECT"));
+
+# ifdef HAS_STD_FILESYSTEM
+    const std::string fileName = static_cast<string>(sm().getFilename(startLoc));
+    if (clazy::endsWith(fileName, ".cpp")) {
+        const std::string basename = std::filesystem::path(fileName).stem().string();
+
+        if (!m_hasAddedMocFile && !m_context->preprocessorVisitor->hasInclude(basename+".moc", false)) {
+            const SourceLocation pos = sm().getLocForEndOfFile(sm().getFileID(startLoc));
+            fixits.push_back(clazy::createInsertion(pos, "\n#include \"" + basename + ".moc\"\n"));
+            m_hasAddedMocFile = true;
+        }
+    }
+# endif
+#endif
+
+    emitWarning(startLoc, record->getQualifiedNameAsString() + " is missing a Q_OBJECT macro", fixits);
 }
 
 void MissingQObjectMacro::registerQ_OBJECT(SourceLocation loc)
