@@ -14,6 +14,9 @@ _verbose = False
 def isWindows():
     return _platform == 'win32'
 
+def isMacOS():
+    return _platform == 'darwin'
+
 class QtInstallation:
     def __init__(self):
         self.int_version = 000
@@ -21,7 +24,12 @@ class QtInstallation:
         self.qmake_lib_path = "/usr/lib"
 
     def compiler_flags(self):
-        return "-isystem " + self.qmake_header_path + ("" if isWindows() else " -fPIC") + " -L " + self.qmake_lib_path
+
+        extra_includes = ''
+        if isMacOS():
+            extra_includes = ' -iframework ' + self.qmake_header_path + '/../lib/ '
+
+        return "-isystem " + self.qmake_header_path + ("" if isWindows() else " -fPIC") + " -L " + self.qmake_lib_path + extra_includes
 
 class Test:
     def __init__(self, check):
@@ -29,6 +37,7 @@ class Test:
         self.minimum_qt_version = 500
         self.maximum_qt_version = 59999
         self.minimum_clang_version = 380
+        self.minimum_clang_version_for_fixits = 380
         self.compare_everything = False
         self.link = False # If true we also call the linker
         self.check = check
@@ -46,6 +55,7 @@ class Test:
         self.ignore_dirs = ""
         self.has_fixits = False
         self.should_run_fixits_test = False
+        self.should_run_on_32bit = True
 
     def filename(self):
         if len(self.filenames) == 1:
@@ -209,6 +219,9 @@ def load_json(check_name):
             else:
                 test.minimum_clang_version = check.minimum_clang_version
 
+            if 'minimum_clang_version_for_fixits' in t:
+                test.minimum_clang_version_for_fixits = t['minimum_clang_version_for_fixits']
+
             if 'blacklist_platforms' in t:
                 test.blacklist_platforms = t['blacklist_platforms']
             if 'compare_everything' in t:
@@ -226,7 +239,7 @@ def load_json(check_name):
             if 'must_fail' in t:
                 test.must_fail = t['must_fail']
             if 'has_fixits' in t:
-                test.has_fixits = t['has_fixits']
+                test.has_fixits = t['has_fixits'] and test.minimum_clang_version_for_fixits <= CLANG_VERSION
             if 'expects_failure' in t:
                 test.expects_failure = t['expects_failure']
             if 'qt4compat' in t:
@@ -239,6 +252,8 @@ def load_json(check_name):
                 test.header_filter = t['header_filter']
             if 'ignore_dirs' in t:
                 test.ignore_dirs = t['ignore_dirs']
+            if 'should_run_on_32bit' in t:
+                test.should_run_on_32bit = t['should_run_on_32bit']
 
             if not test.checks:
                 test.checks.append(test.check.name)
@@ -404,8 +419,12 @@ except:
     try:
         version = match.group(1)
     except:
-        print("Could not determine clang version, is it in PATH?")
-        sys.exit(-1)
+        splitted = version.split()
+        if len(splitted) > 2:
+            version = splitted[2]
+        else:
+            print("Could not determine clang version, is it in PATH?")
+            sys.exit(-1)
 
 if _verbose:
     print('Found clang version: ' + str(version))
@@ -505,7 +524,8 @@ def patch_fixit_yaml_file(test, is_standalone):
             line = line.replace(test.relativeFilename().replace('/', '\\'), fixedfilename.replace('/', '\\'))
 
             # Some tests also apply fix their to their headers:
-            line = line.replace(possible_headerfile, fixedfilename.replace(".cpp", ".h"))
+            if not test.relativeFilename().endswith(".hh"):
+                line = line.replace(possible_headerfile, fixedfilename.replace(".cpp", ".h"))
         f.write(line)
     f.close()
 
@@ -558,6 +578,9 @@ def file_contains(filename, text):
     f.close()
     return text in contents
 
+def is32Bit():
+    return platform.architecture()[0] == '32bit'
+
 def run_unit_test(test, is_standalone):
     if test.check.clazy_standalone_only and not is_standalone:
         return True
@@ -579,6 +602,11 @@ def run_unit_test(test, is_standalone):
             print("Skipping " + test.check.name + " because it is blacklisted for this platform")
         return True
 
+    if not test.should_run_on_32bit and is32Bit():
+        if (_verbose):
+            print("Skipping " + test.check.name + " because it is blacklisted on 32bit")
+        return True;
+
     checkname = test.check.name
     filename = checkname + "/" + test.filename()
 
@@ -587,7 +615,7 @@ def run_unit_test(test, is_standalone):
     expected_file = filename + ".expected"
 
     # Some tests have different output on 32 bit
-    if platform.architecture()[0] == '32bit' and os.path.exists(expected_file + '.x86'):
+    if is32Bit() and os.path.exists(expected_file + '.x86'):
         expected_file = expected_file + '.x86'
 
     if is_standalone and test.isScript():
